@@ -152,6 +152,22 @@ impl Matcher {
         let source = self.remove_markdown_comment(&source)?;
         let target = self.revert_code_comment(&target);
 
+        // Prevent unexpected diff at the following case
+        //
+        //   aaa           <!--
+        //          vs     aaa
+        //                 -->
+        //                 aaa
+        //
+        // The additional trailing '\n' prevent to match the last line of target with the first line of source.
+        let source_trailing_new_lines = source.len() - source.trim_end_matches('\n').len();
+        let target_trailing_new_lines = target.len() - target.trim_end_matches('\n').len();
+        let additional_new_lines = usize::max(source_trailing_new_lines, target_trailing_new_lines)
+            - target_trailing_new_lines
+            + 1;
+        let mut target = target.to_string();
+        target.push_str(&"\n".repeat(additional_new_lines));
+
         let (mismatch_lines, right_only_lines) = Matcher::get_mismatch_lines(&source, &target);
 
         let mut lines = Vec::new();
@@ -445,6 +461,23 @@ mod test {
         assert_eq!(ret[0].1[2].content, "        eee");
     }
 
+    #[test]
+    fn test_keep_original_line() {
+        let source = r##"
+aaa
+            "##;
+        let target = r##"
+<!--
+aaa
+-->
+aaa
+
+            "##;
+
+        let (ret, _) = Matcher::get_mismatch_lines(source, target);
+        assert_eq!(ret.len(), 0);
+    }
+
     #[test]
     fn test_check_dir() {
         let matcher = Matcher {
@@ -466,18 +499,21 @@ mod test {
             Mismatch::MismatchLines(x) => x.source_path.clone(),
             Mismatch::MissingFile(x) => x.source_path.clone(),
         });
-        assert_eq!(ret.len(), 4);
+        assert_eq!(ret.len(), 5);
         assert!(
-            matches!(&ret[0], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "comment.md" && x.lines.is_empty())
+            matches!(&ret[0], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "01_hello.md" && x.lines.is_empty())
         );
         assert!(
-            matches!(&ret[1], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "hello.md" && x.lines.is_empty())
+            matches!(&ret[1], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "02_comment.md" && x.lines.is_empty())
         );
         assert!(
-            matches!(&ret[2], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "mismatch_lines.md" && !x.lines.is_empty())
+            matches!(&ret[2], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "03_mismatch_lines.md" && !x.lines.is_empty())
         );
         assert!(
-            matches!(&ret[3], Mismatch::MissingFile(x) if x.source_path.file_name().unwrap() == "missing_file.md")
+            matches!(&ret[3], Mismatch::MissingFile(x) if x.source_path.file_name().unwrap() == "04_missing_file.md")
+        );
+        assert!(
+            matches!(&ret[4], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "05_keep_original.md" && x.lines.is_empty())
         );
     }
 
@@ -510,16 +546,16 @@ mod test {
         });
         assert_eq!(ret.len(), 4);
         assert!(
-            matches!(&ret[0], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "comment.md" && x.lines.is_empty())
+            matches!(&ret[0], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "01_hello.md" && x.lines.is_empty())
         );
         assert!(
-            matches!(&ret[1], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "hello.md" && x.lines.is_empty())
+            matches!(&ret[1], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "02_comment.md" && x.lines.is_empty())
         );
         assert!(
-            matches!(&ret[2], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "mismatch_lines.md" && !x.lines.is_empty())
+            matches!(&ret[2], Mismatch::MismatchLines(x) if x.source_path.file_name().unwrap() == "03_mismatch_lines.md" && !x.lines.is_empty())
         );
         assert!(
-            matches!(&ret[3], Mismatch::MissingFile(x) if x.source_path.file_name().unwrap() == "missing_file.md")
+            matches!(&ret[3], Mismatch::MissingFile(x) if x.source_path.file_name().unwrap() == "04_missing_file.md")
         );
     }
 }
